@@ -170,10 +170,10 @@ CCanvas::~CCanvas() {
   saveSizeTrackProfile();
 
   /* stop running drawing-threads and don't destroy unless they have finished*/
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     context->quit();
   }
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     context->wait();
   }
 
@@ -315,11 +315,7 @@ void CCanvas::buildHelpText() {
 
   const QString& msgDEMLinks =
       tr("<h2>&nbsp;</h2>"
-         "<p>Impatient Users:<p>"
-         "<ul>"
-         "<li><a href='GetDems'>I want some online DEMs.</a></li>"
-         "</ul>"
-         "<p>Patient Users:<p>"
+
          "<ul>"
          "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocMapDemSources'>Sources for DEM</a></li>"
          "</ul>");
@@ -339,10 +335,7 @@ void CCanvas::buildHelpText() {
          "reference one "
          "or several other files. Again, you can use QMapShack's built-in VRT Builder (<a href='VrtBuilder'>Tool->VRT "
          "Builder</a>) "
-         "to create such a file.</p>"
-         "<p>To start with some online DEMs you can click on the link for <a href='GetDems'>impatient users</a>. But "
-         "keep in mind "
-         "that using online DEMs slows down QMapShack significantly.</p>");
+         "to create such a file.</p>");
 
   addHtmlRow(msg, msgDEMLinks, msgDem, "", "");
 
@@ -476,7 +469,7 @@ void CCanvas::reportStatus(const QString& key, const QString& msg) {
   QString report;
   QStringList keys = statusMessages.keys();
   keys.sort();
-  for (const QString& key : qAsConst(keys)) {
+  for (const QString& key : std::as_const(keys)) {
     report += statusMessages[key] + "\n";
   }
 
@@ -487,11 +480,13 @@ void CCanvas::reportStatus(const QString& key, const QString& msg) {
     textStatusMessages->show();
     textStatusMessages->setText(report);
 
-    qreal h;
-    h = height() - Y_OFF_STATUS - getTrackProfileSize(height()).height() - 40;
-    h = qMin(h, textStatusMessages->document()->size().height() + 10);
-    textStatusMessages->setMinimumHeight(h);
-    textStatusMessages->setMaximumHeight(h);
+    if (isVisible()) {
+      qreal h;
+      h = height() - Y_OFF_STATUS - getTrackProfileSize(height()).height() - 40;
+      h = qMin(h, textStatusMessages->document()->size().height() + 10);
+      textStatusMessages->setMinimumHeight(h);
+      textStatusMessages->setMaximumHeight(h);
+    }
   }
   update();
 }
@@ -599,8 +594,9 @@ void CCanvas::mousePressEvent(QMouseEvent* e) {
 void CCanvas::mouseMoveEvent(QMouseEvent* e) {
   QPointF pos = e->pos();
   map->convertPx2Rad(pos);
-  qreal ele = dem->getElevationAt(pos, true);
-  qreal slope = dem->getSlopeAt(pos, true);
+  qreal ele = dem->getElevationAt(pos, false);
+  qreal slope = dem->getSlopeAt(pos, false);
+
   emit sigMousePosition(pos * RAD_TO_DEG, ele, slope);
 
   mouse->mouseMoveEvent(e);
@@ -649,7 +645,7 @@ void CCanvas::wheelEvent(QWheelEvent* e) {
   update();
 }
 
-void CCanvas::enterEvent(QEvent* e) {
+void CCanvas::enterEvent(QEnterEvent* e) {
   if (labelHelp->isVisible()) {
     return;
   }
@@ -813,7 +809,7 @@ void CCanvas::slotToolTip() {
     }
   }
   QPoint p = mapToGlobal(posToolTip + QPoint(32, 0));
-  QToolTip::showText(p, str);
+  QToolTip::showText(p, str, this);
 }
 
 void CCanvas::slotCheckTrackOnFocus() {
@@ -1015,7 +1011,7 @@ void CCanvas::setup() {
 QString CCanvas::getProjection() { return map->getProjection(); }
 
 void CCanvas::setProjection(const QString& proj) {
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     if (!context->setProjection(proj)) {
       QMessageBox::warning(this, tr("Map Projection..."),
                            tr("Failed to setup map projection. Please configure a valid projection."), QMessageBox::Ok);
@@ -1027,14 +1023,16 @@ void CCanvas::setProjection(const QString& proj) {
 }
 
 void CCanvas::setScales(const scales_type_e type) {
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     context->setScales(type);
   }
 }
 
 CCanvas::scales_type_e CCanvas::getScalesType() { return map->getScalesType(); }
 
-qreal CCanvas::getElevationAt(const QPointF& pos) const { return dem->getElevationAt(pos); }
+qreal CCanvas::getElevationAt(const QPointF& pos, bool checkScale) const {
+  return dem->getElevationAt(pos, checkScale);
+}
 
 void CCanvas::getElevationAt(const QPolygonF& pos, QPolygonF& ele) const { return dem->getElevationAt(pos, ele); }
 
@@ -1137,7 +1135,7 @@ void CCanvas::showProfile(bool yes) {
 
 bool CCanvas::setDrawContextSize(const QSize& s) {
   bool done = true;
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     done &= context->resize(s);
   }
   return done;
@@ -1155,15 +1153,15 @@ void CCanvas::print(QPainter& p, const QRectF& area, const QPointF& focus, bool
 
   redraw_e redraw = eRedrawAll;
 
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     context->draw(p, redraw, focus);
   }
 
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     context->wait();
   }
 
-  for (IDrawContext* context : qAsConst(allDrawContext)) {
+  for (IDrawContext* context : std::as_const(allDrawContext)) {
     context->draw(p, redraw, focus);
   }
 
