@@ -42,13 +42,9 @@ enum event_types_e {
   eEvtD2WHideItems = QEvent::User + 5,
   eEvtD2WUpdateLnF = QEvent::User + 6,
   eEvtD2WUpdateItems = QEvent::User + 7,
-  eEvtD2WReload = QEvent::User + 8
-
-  ,
+  eEvtD2WReload = QEvent::User + 8,
   eEvtW2DAckInfo = QEvent::User + 100,
-  eEvtW2DCreate = QEvent::User + 101
-
-  ,
+  eEvtW2DCreate = QEvent::User + 101,
   eEvtA2WCutTrk = QEvent::User + 200,
   eEvtA2WSave = QEvent::User + 201,
   eEvtA2WSync = QEvent::User + 202
@@ -391,6 +387,8 @@ class CGisWorkspace : public QWidget, private Ui::IGisWorkspace {
 
   const CSearch& getCurrentSearch() const { return currentSearch; }
 
+  const CGisListWks& getWksList() const { return *treeWks; }
+
  signals:
   void sigChanged();
 
