@@ -23,29 +23,116 @@
 
 #include "gis/CGisListWks.h"
 #include "gis/IWksItem.h"
+#include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/IGisProject.h"
+#include "gis/rte/CGisItemRte.h"
 #include "gis/search/CGeoSearch.h"
+#include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
 #include "helpers/CDraw.h"
+#include "helpers/CSettings.h"
+#include "misc.h"
 
 constexpr int kMargin = 1;
 constexpr int kFontSizeDiffProject = 2;
 constexpr int kFontSizeDiffItem = 3;
+constexpr int kFontSizeInvalid = -1;
 
-CWksItemDelegate::CWksItemDelegate(CGisListWks* parent) : QStyledItemDelegate(parent), treeWidget(parent) {}
+CWksItemDelegate::CWksItemDelegate(CGisListWks* parent) : QStyledItemDelegate(parent), treeWidget(parent) {
+  SETTINGS;
+  cfg.beginGroup("Workspace");
+  cfg.beginGroup("Decorations");
+  itemStatusControl.prj.flags = cfg.value("prj", itemStatusControl.prj.flags).toUInt();
+  itemStatusControl.trk.flags = cfg.value("trk", itemStatusControl.trk.flags).toUInt();
+  itemStatusControl.wpt.flags = cfg.value("wpt", itemStatusControl.wpt.flags).toUInt();
+  itemStatusControl.rte.flags = cfg.value("rte", itemStatusControl.rte.flags).toUInt();
+  itemStatusControl.area.flags = cfg.value("area", itemStatusControl.area.flags).toUInt();
+  itemStatusControl.statusSizePrj = cfg.value("statusSizePrj", kFontSizeDiffProject).toInt();
+  itemStatusControl.statusSizeItem = cfg.value("statusSizeItem", kFontSizeDiffItem).toInt();
+  cfg.endGroup();  // Decorations
+  cfg.endGroup();  // Workspace
+}
+
+void CWksItemDelegate::setStatusItemsControl(const item_status_ctrl_t& settings) {
+  itemStatusControl = settings;
+
+  SETTINGS;
+  cfg.beginGroup("Workspace");
+  cfg.beginGroup("Decorations");
+  cfg.setValue("prj", itemStatusControl.prj.flags);
+  cfg.setValue("trk", itemStatusControl.trk.flags);
+  cfg.setValue("wpt", itemStatusControl.wpt.flags);
+  cfg.setValue("rte", itemStatusControl.rte.flags);
+  cfg.setValue("area", itemStatusControl.area.flags);
+  cfg.setValue("statusSizePrj", itemStatusControl.statusSizePrj);
+  cfg.setValue("statusSizeItem", itemStatusControl.statusSizeItem);
+  cfg.endGroup();  // Decorations
+  cfg.endGroup();  // Workspace
+
+  emit treeWidget->model()->layoutChanged();
+}
 
 IWksItem* CWksItemDelegate::indexToItem(const QModelIndex& index) const {
   IWksItem* item = dynamic_cast<IWksItem*>(treeWidget->itemFromIndex(index));
   return item;
 }
 
+QSize CWksItemDelegate::sizeHint(const QStyleOptionViewItem& opt, const QModelIndex& index) const {
+  const IWksItem* item = indexToItem(index);
+  if (item == nullptr) {
+    return QSize(opt.rect.width(), 22);
+  }
+
+  QFont fontName = opt.font;
+  fontName.setBold(true);
+  QFontMetrics fmName(fontName);
+
+  QFont fontStatusPrj = opt.font;
+  fontStatusPrj.setPointSize(fontName.pointSize() - itemStatusControl.statusSizePrj);
+  QFontMetrics fmStausPrj(fontStatusPrj);
+
+  QFont fontStatusItem = opt.font;
+  fontStatusItem.setPointSize(fontName.pointSize() - itemStatusControl.statusSizeItem);
+  QFontMetrics fmStatusItem(fontStatusItem);
+
+  QFont fontStatusOther = opt.font;
+  fontStatusOther.setPointSize(fontName.pointSize() - kFontSizeDiffProject);
+  QFontMetrics fmStatusOther(fontStatusOther);
+
+  switch (item->getBaseType()) {
+    case IWksItem::eBaseType::Project:
+      if (itemStatusControl.statusSizePrj != kFontSizeInvalid) {
+        return QSize(opt.rect.width(), std::max(22, 7 * kMargin + fmName.height() + fmStausPrj.height()));
+      } else {
+        return QSize(opt.rect.width(), std::max(22, 5 * kMargin + fmName.height()));
+      }
+
+    case IWksItem::eBaseType::GeoSearch:
+    case IWksItem::eBaseType::Device:
+      return QSize(opt.rect.width(), std::max(22, 7 * kMargin + fmName.height() + fmStatusOther.height()));
+
+    case IWksItem::eBaseType::GeoSearchError:
+      return QSize(opt.rect.width(), std::max(22, 5 * kMargin + fmName.height()));
+
+    case IWksItem::eBaseType::Item:
+      if (itemStatusControl.statusSizeItem != kFontSizeInvalid) {
+        return QSize(opt.rect.width(), std::max(22, 7 * kMargin + fmName.height() + fmStatusItem.height()));
+      } else {
+        return QSize(opt.rect.width(), std::max(22, 5 * kMargin + fmName.height()));
+      }
+
+    default:;
+      return QSize(opt.rect.width(), 22);
+  }
+}
+
 std::tuple<QFont, QFont, QRect, QRect, QRect, QRect, QRect, QRect, QRect> CWksItemDelegate::getRectanglesProject(
     const QStyleOptionViewItem& opt, IWksItem& item) const {
   const QFont fontName = opt.font;
   const QFontMetrics fmName(fontName);
 
   QFont fontStatus = opt.font;
-  fontStatus.setPointSize(fontStatus.pointSize() - kFontSizeDiffProject);
+  fontStatus.setPointSize(fontStatus.pointSize() - itemStatusControl.statusSizePrj);
   const QFontMetrics fmStatus(fontStatus);
 
   const QRect& r = opt.rect.adjusted(2 * kMargin, 2 * kMargin, -2 * kMargin, -2 * kMargin);
@@ -74,7 +161,7 @@ std::tuple<QFont, QFont, QRect, QRect, QRect, QRect, QRect, QRect, QRect> CWksIt
   QRect rectSave;
   QRect rectAutoSyncDev;
 
-  if (isOnDevice == false) {
+  if (isOnDevice == false && item.type() != IWksItem::eTypeLostFound) {
     if (item.holdUiFocus(opt)) {
       rectActiveProject.setRect(left, buttonTop, buttonWidth, buttonHeight);
       left -= buttonWidth + kMargin;
@@ -95,13 +182,21 @@ std::tuple<QFont, QFont, QRect, QRect, QRect, QRect, QRect, QRect, QRect> CWksIt
         left -= buttonWidth + kMargin;
       }
     }
+  } else if (isOnDevice == true) {
+    if (item.holdUiFocus(opt)) {
+      rectSave.setRect(left, buttonTop, buttonWidth, buttonHeight);
+      left -= buttonWidth + kMargin;
+    }
   }
   // As rectName should span up to the right of the last button left has
   // to be corrected by a button width.
   rectName.setRight(left + buttonWidth - 2 * kMargin);
 
-  const QRect rectStatus(rectIcon.right() + 2 * kMargin, r.bottom() - fmStatus.height(),
-                         r.width() - rectIcon.width() - 2 * kMargin, fmStatus.height());
+  QRect rectStatus;
+  if (itemStatusControl.statusSizePrj != kFontSizeInvalid) {
+    rectStatus.setRect(rectIcon.right() + 2 * kMargin, r.bottom() - fmStatus.height(),
+                       r.width() - rectIcon.width() - 2 * kMargin, fmStatus.height());
+  }
 
   return {fontName,    fontStatus, rectIcon,          rectName,       rectStatus,
           rectVisible, rectSave,   rectActiveProject, rectAutoSyncDev};
@@ -113,7 +208,7 @@ std::tuple<QFont, QFont, QRect, QRect, QRect, QRect> CWksItemDelegate::getRectan
   QFontMetrics fmName(fontName);
 
   QFont fontStatus = opt.font;
-  fontStatus.setPointSize(fontStatus.pointSize() - kFontSizeDiffItem);
+  fontStatus.setPointSize(fontStatus.pointSize() - itemStatusControl.statusSizeItem);
   QFontMetrics fmStatus(fontStatus);
 
   const QRect& r = opt.rect.adjusted(2 * kMargin, 2 * kMargin, -2 * kMargin, -2 * kMargin);
@@ -149,8 +244,11 @@ std::tuple<QFont, QFont, QRect, QRect, QRect, QRect> CWksItemDelegate::getRectan
   // to be corrected by a button width.
   rectName.setRight(left + buttonWidth - 2 * kMargin);
 
-  const QRect rectStatus(rectIcon.right() + 2 * kMargin, r.bottom() - fmStatus.height(),
-                         r.width() - rectIcon.width() - 2 * kMargin, fmStatus.height());
+  QRect rectStatus;
+  if (itemStatusControl.statusSizeItem != kFontSizeInvalid) {
+    rectStatus = QRect(rectIcon.right() + 2 * kMargin, r.bottom() - fmStatus.height(),
+                       r.width() - rectIcon.width() - 2 * kMargin, fmStatus.height());
+  }
 
   return {fontName, fontStatus, rectIcon, rectName, rectStatus, rectChanged};
 }
@@ -166,14 +264,11 @@ std::tuple<QFont, QFont, QRect, QRect, QRect, QRect> CWksItemDelegate::getRectan
 
   const QRect& r = opt.rect.adjusted(2 * kMargin, 2 * kMargin, -2 * kMargin, -2 * kMargin);
   const QRect& rectIcon = r.adjusted(-kMargin, -kMargin, -(r.width() - r.height()), kMargin);
-
   const QRect rectVisible(r.right() - fmName.height(), r.top(), fmName.height(), fmName.height());
-
   const QRect rectName(rectIcon.right() + kMargin, r.top(),
                        r.width() - rectIcon.width() - rectVisible.width() - 2 * kMargin, fmName.height());
-
   const QRect rectStatus(rectIcon.right() + kMargin, r.bottom() - fmStatus.height(),
-                         r.width() - rectIcon.width() - 2 * kMargin, fmStatus.height());
+                       r.width() - rectIcon.width() - 2 * kMargin, fmStatus.height());
 
   return {fontName, fontStatus, rectIcon, rectName, rectStatus, rectVisible};
 }
@@ -184,25 +279,20 @@ std::tuple<QFont, QFont, QRect, QRect, QRect, QRect, QRect, QRect> CWksItemDeleg
   const QFontMetrics fmSearch(fontSearch);
 
   QFont fontStatus = opt.font;
-  fontStatus.setPointSize(fontStatus.pointSize() - kFontSizeDiffItem);
+  fontStatus.setPointSize(fontStatus.pointSize() - kFontSizeDiffProject);
   const QFontMetrics fmStatus(fontStatus);
 
   const QRect& r = opt.rect.adjusted(2 * kMargin, 2 * kMargin, -2 * kMargin, -2 * kMargin);
   const quint32 height = r.height() / 2;
 
   const QRect rectIcon(r.left(), r.top(), r.height(), r.height());
-
   const QRect rectSetup(rectIcon.right() + kMargin, r.top(), height, height);
-
   const QRect rectVisible(r.right() - fmSearch.height(), r.top(), height, height);
-
   const QRect rectWptIcon(rectVisible.left() - height - kMargin, r.top(), height, height);
-
   const QRect rectLineEdit(
       rectSetup.right() + kMargin, r.top(),
       r.width() - rectSetup.width() - rectIcon.width() - rectWptIcon.width() - rectVisible.width() - 4 * kMargin,
       height + 4 * kMargin);
-
   const QRect rectStatus(
       rectSetup.right() + kMargin, r.bottom() - fmStatus.height(),
       r.width() - rectSetup.width() - rectIcon.width() - rectWptIcon.width() - rectVisible.width() - 4 * kMargin,
@@ -237,44 +327,19 @@ void CWksItemDelegate::drawToolButton(QPainter* p, const QStyleOptionViewItem& o
   opt.widget->style()->drawComplexControl(QStyle::CC_ToolButton, &btnOpt, p, opt.widget);
 }
 
-QSize CWksItemDelegate::sizeHint(const QStyleOptionViewItem& opt, const QModelIndex& index) const {
-  const IWksItem* item = indexToItem(index);
-  if (item == nullptr) {
-    return QSize(opt.rect.width(), 22);
-  }
-
-  QFont font1 = opt.font;
-  font1.setBold(true);
-  QFontMetrics fm1(font1);
-
-  QFont font2 = opt.font;
-  font2.setPointSize(font2.pointSize() - kFontSizeDiffProject);
-  QFontMetrics fm2(font2);
-
-  QFont font3 = opt.font;
-  font3.setPointSize(font3.pointSize() - kFontSizeDiffItem);
-  QFontMetrics fm3(font3);
-
-  // qDebug() << fm1.height() << fm2.height() << (3 * kMargin + fm1.height() + fm2.height());
-  // qDebug() << fm1.height() << fm3.height() << (3 * kMargin + fm1.height() + fm3.height());
-
-  switch (item->getBaseType()) {
-    case IWksItem::eBaseType::Project:
-    case IWksItem::eBaseType::GeoSearch:
-    case IWksItem::eBaseType::Device:
-      return QSize(opt.rect.width(), std::max(32, 5 * kMargin + fm1.height() + fm2.height()));
-    case IWksItem::eBaseType::GeoSearchError:
-    case IWksItem::eBaseType::Item:
-      return QSize(opt.rect.width(), std::max(22, 5 * kMargin + fm1.height() + fm3.height()));
-
-    default:;
-      return QSize(opt.rect.width(), 22);
+void CWksItemDelegate::drawRatingStars(qreal rating, QPainter* p, QIcon::Mode iconMode, QRect& rectStatus) const {
+  const qint32 N = qRound(rating);
+  if (rating != 0) {
+    QRect rectStar(rectStatus.left() + kMargin, rectStatus.top() + kMargin, rectStatus.height() - 2 * kMargin,
+                   rectStatus.height() - 2 * kMargin);
+    for (int i = 0; i < N; i++) {
+      QIcon("://icons/cache/32x32/star.png").paint(p, rectStar, Qt::AlignCenter, iconMode);
+      rectStar.translate(kMargin + rectStar.width(), 0);
+    }
+    rectStatus.setLeft(rectStar.left() + kMargin);
   }
 }
 
-void CWksItemDelegate::initStyleOption(QStyleOptionViewItem* option, const QModelIndex& index) const {
-  QStyledItemDelegate::initStyleOption(option, index);
-}
 
 void CWksItemDelegate::paint(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index) const {
   IWksItem* item = indexToItem(index);
@@ -344,19 +409,25 @@ void CWksItemDelegate::paintProject(QPainter* p, const QStyleOptionViewItem& opt
   const float opacityOfFocusBasedItems = item.getOpacityOfFocusBasedItems();
 
   if (rectSave.isValid()) {
-    // draw save/ auto save button
-    if (item.isChanged() && !item.isAutoSave()) {
-      // show save button
-      drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/Save.png"), true, false);
+    if (item.isOnDevice() == false) {
+      // draw save/ auto save button
+      if (item.isChanged() && !item.isAutoSave()) {
+        // show save button
+        drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/Save.png"), true, false);
+      } else {
+        p->setOpacity(opacityOfFocusBasedItems);
+        if (item.isAutoSave()) {
+          // show auto save button pressed, to disable autosave
+          drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/AutoSaveA.png"), true, true);
+        } else if (item.canSave()) {
+          // show auto save button only if project can be saved
+          drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/AutoSaveNoA.png"), true, false);
+        }
+        p->setOpacity(1.0);
+      }
     } else {
       p->setOpacity(opacityOfFocusBasedItems);
-      if (item.isAutoSave()) {
-        // show auto save button pressed, to disable autosave
-        drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/AutoSaveA.png"), true, true);
-      } else if (item.canSave()) {
-        // show auto save button only if project can be saved
-        drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/AutoSaveNoA.png"), true, false);
-      }
+      drawToolButton(p, opt, rectSave, QIcon(":/icons/32x32/Copy.png"), true, false);
       p->setOpacity(1.0);
     }
   }
@@ -392,14 +463,59 @@ void CWksItemDelegate::paintProject(QPainter* p, const QStyleOptionViewItem& opt
   p->drawText(rectName.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop,
               isOnDevice ? project->getName() : project->getNameEx());
 
-  QString status;
-  const QString& keywords = project->getKeywords();
-  if (!keywords.isEmpty()) {
-    status += keywords + " ";
+  // -- start ------------ status line ---------------------------------------
+  if (rectStatus.isValid()) {
+    QString status;
+    const QString& keywords = project->getKeywords();
+    if (!keywords.isEmpty() && itemStatusControl.prj.keywords) {
+      status += keywords + " ";
+    }
+
+    qreal distance = project->getTotalDistance();
+    if (distance < NOFLOAT && !qFuzzyIsNull(distance) && itemStatusControl.prj.distance) {
+      QString unit, val;
+      IUnit::self().meter2distance(distance, val, unit);
+      status += QString("%1%2%3 ").arg(QChar(0x21A6)).arg(val, unit);
+    }
+
+    qreal ascent = project->getTotalAscent();
+    if (ascent < NOFLOAT && !qFuzzyIsNull(ascent) && itemStatusControl.prj.ascent) {
+      QString unit, val;
+      IUnit::self().meter2elevation(ascent, val, unit);
+      status += QString("%1%2%3 ").arg(QChar(0x2197)).arg(val, unit);
+    }
+
+    qreal descent = project->getTotalDescent();
+    if (descent < NOFLOAT && !qFuzzyIsNull(descent) && itemStatusControl.prj.descent) {
+      QString unit, val;
+      IUnit::self().meter2elevation(descent, val, unit);
+      status += QString("%1%2%3 ").arg(QChar(0x2198)).arg(val, unit);
+    }
+
+    if (itemStatusControl.prj.gisStats) {
+      const IGisProject* const prj = dynamic_cast<IGisProject*>(&item);
+      const qint32 cntTrk = prj->getItemCountByType(IGisItem::eTypeTrk);
+      if (cntTrk != 0) {
+        status += QString("T: %1 ").arg(cntTrk);
+      }
+      const qint32 cntWpt = prj->getItemCountByType(IGisItem::eTypeWpt);
+      if (cntWpt != 0) {
+        status += QString("W: %1 ").arg(cntWpt);
+      }
+      const qint32 cntRte = prj->getItemCountByType(IGisItem::eTypeRte);
+      if (cntRte != 0) {
+        status += QString("R: %1 ").arg(cntRte);
+      }
+      const qint32 cntArea = prj->getItemCountByType(IGisItem::eTypeOvl);
+      if (cntArea != 0) {
+        status += QString("A: %1 ").arg(cntArea);
+      }
+    }
+    p->setPen(colorName);
+    p->setFont(fontStatus);
+    p->drawText(rectStatus.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop, status);
   }
-  p->setPen(colorName);
-  p->setFont(fontStatus);
-  p->drawText(rectStatus.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop, status);
+  // -- stop ------------ status line ---------------------------------------
 }
 
 void CWksItemDelegate::paintDevice(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index,
@@ -446,31 +562,101 @@ void CWksItemDelegate::paintItem(QPainter* p, const QStyleOptionViewItem& opt, c
   p->setFont(fontName);
   p->drawText(rectName.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop, item.getName());
 
-  // draw rating
-  qint32 rating = qRound(item.getRating());
-  if (rating != 0) {
-    QRect rectStar(rectStatus.left(), rectStatus.top(), rectStatus.height(), rectStatus.height());
-    for (int i = 0; i < qRound(item.getRating()); i++) {
-      QIcon("://icons/cache/32x32/star.png").paint(p, rectStar, Qt::AlignCenter, iconMode);
-      rectStar.translate(kMargin + rectStar.width(), 0);
+  // -- start ------------ status line ---------------------------------------
+  if (rectStatus.isValid()) {
+    QString status;
+    const CGisItemTrk* trk = dynamic_cast<const CGisItemTrk*>(&item);
+    if (trk != nullptr && itemStatusControl.trk.flags != 0) {
+      if (itemStatusControl.trk.rating) {
+        drawRatingStars(item.getRating(), p, iconMode, rectStatus);
+      }
+
+      if (itemStatusControl.trk.tags) {
+        status = item.getTags().values().join(", ");
+        if (!status.isEmpty()) {
+          status += " ";
+        }
+      }
+
+      qreal distance = trk->getTotalDistance();
+      if (distance != NOFLOAT && !qFuzzyIsNull(distance) && itemStatusControl.trk.distance) {
+        QString unit, val;
+        IUnit::self().meter2distance(distance, val, unit);
+        status += QString("%1%2%3 ").arg(QChar(0x21A6)).arg(val, unit);
+      }
+
+      qreal ascent = trk->getTotalAscent();
+      if (ascent != NOFLOAT && !qFuzzyIsNull(ascent) && itemStatusControl.trk.ascent) {
+        QString unit, val;
+        IUnit::self().meter2elevation(ascent, val, unit);
+        status += QString("%1%2%3 ").arg(QChar(0x2197)).arg(val, unit);
+      }
+
+      qreal descent = trk->getTotalDescent();
+      if (descent != NOFLOAT && !qFuzzyIsNull(descent) && itemStatusControl.trk.descent) {
+        QString unit, val;
+        IUnit::self().meter2elevation(descent, val, unit);
+        status += QString("%1%2%3 ").arg(QChar(0x2198)).arg(val, unit);
+      }
     }
-    rectStatus.setLeft(rectStar.left() + kMargin);
-  }
 
-  // draw tags
-  const QSet<QString>& tags = item.getTags();
-  if (!tags.isEmpty()) {
-    // draw tags
-    p->setFont(fontStatus);
-    p->drawText(rectStatus.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop, tags.values().join(", "));
-  }
+    const CGisItemWpt* wpt = dynamic_cast<const CGisItemWpt*>(&item);
+    if (wpt != nullptr) {
+      if (wpt->isGeocache()) {
+        status = wpt->getGeoCache().name;
+      } else if (itemStatusControl.wpt.flags != 0) {
+        if (itemStatusControl.wpt.rating) {
+          drawRatingStars(item.getRating(), p, iconMode, rectStatus);
+        }
+
+        if (itemStatusControl.wpt.tags) {
+          status = item.getTags().values().join(", ");
+          if (!status.isEmpty()) {
+            status += " ";
+          }
+        }
+
+        qreal ele = wpt->getElevation();
+        if (ele != NOFLOAT && ele != NOFLOAT && itemStatusControl.wpt.elevation) {
+          QString unit, val;
+          IUnit::self().meter2elevation(ele, val, unit);
+          status += QString("%1%2 ").arg(val, unit);
+        }
+      }
+    }
+
+    const CGisItemRte* rte = dynamic_cast<const CGisItemRte*>(&item);
+    if (rte != nullptr && itemStatusControl.rte.flags != 0) {
+      if (itemStatusControl.rte.rating) {
+        drawRatingStars(item.getRating(), p, iconMode, rectStatus);
+      }
+
+      if (itemStatusControl.rte.tags) {
+        status = item.getTags().values().join(", ");
+        if (!status.isEmpty()) {
+          status += " ";
+        }
+      }
+    }
+
+    const CGisItemOvlArea* area = dynamic_cast<const CGisItemOvlArea*>(&item);
+    if (area != nullptr && itemStatusControl.area.flags != 0) {
+      if (itemStatusControl.area.rating) {
+        drawRatingStars(item.getRating(), p, iconMode, rectStatus);
+      }
+
+      if (itemStatusControl.area.tags) {
+        status = item.getTags().values().join(", ");
+        if (!status.isEmpty()) {
+          status += " ";
+        }
+      }
+    }
 
-  const CGisItemWpt* wpt = dynamic_cast<const CGisItemWpt*>(&item);
-  if (wpt != nullptr && wpt->isGeocache()) {
-    // draw cache name
     p->setFont(fontStatus);
-    p->drawText(rectStatus.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop, wpt->getGeoCache().name);
+    p->drawText(rectStatus.adjusted(0, -1, 0, 1), Qt::AlignLeft | Qt::AlignTop, status);
   }
+  // -- stop ------------ status line ---------------------------------------
 
   // draw icon
   QIcon(item.getIcon()).paint(p, rectIcon, Qt::AlignCenter, iconMode);
@@ -516,7 +702,7 @@ void CWksItemDelegate::paintGeoSearch(QPainter* p, const QStyleOptionViewItem& o
 
   p->setPen(colorStatus);
   p->setFont(fontStatus);
-  p->drawText(rectStatus.adjusted(kMargin, -1, 1, 0), Qt::AlignTop | Qt::AlignLeft, search->getServiceName());
+  p->drawText(rectStatus.adjusted(kMargin, -1, 0, 1), Qt::AlignTop | Qt::AlignLeft, search->getServiceName());
 }
 
 void CWksItemDelegate::paintGeoSearchError(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index,
@@ -529,7 +715,7 @@ void CWksItemDelegate::paintGeoSearchError(QPainter* p, const QStyleOptionViewIt
 
   p->setPen(color);
   p->setFont(font);
-  p->drawText(rectName.adjusted(kMargin, 0, 0, 0), Qt::AlignTop | Qt::AlignLeft, item.getName());
+  p->drawText(rectName.adjusted(kMargin, -1, 0, 1), Qt::AlignTop | Qt::AlignLeft, item.getName());
 }
 
 bool CWksItemDelegate::editorEvent(QEvent* event, QAbstractItemModel* model, const QStyleOptionViewItem& opt,
@@ -564,22 +750,26 @@ bool CWksItemDelegate::mousePressProject(QMouseEvent* me, const QStyleOptionView
     emit sigUpdateCanvas();
     return true;
   } else if (rectSave.contains(me->pos())) {
-    if (item.isAutoSave()) {
-      item.setAutoSave(false);
-    } else {
-      if (item.isChanged()) {
-        IGisProject* project = dynamic_cast<IGisProject*>(&item);
-        if (project == nullptr) {
-          return false;
-        }
-        if (project->canSave()) {
-          project->save();
-        } else {
-          project->saveAs();
-        }
+    if (item.isOnDevice() == false) {
+      if (item.isAutoSave()) {
+        item.setAutoSave(false);
       } else {
-        item.setAutoSave(true);
+        if (item.isChanged()) {
+          IGisProject* project = dynamic_cast<IGisProject*>(&item);
+          if (project == nullptr) {
+            return false;
+          }
+          if (project->canSave()) {
+            project->save();
+          } else {
+            project->saveAs();
+          }
+        } else {
+          item.setAutoSave(true);
+        }
       }
+    } else {
+      treeWidget->slotCopyProject();
     }
     return true;
   } else if (rectAutoSyncDev.contains(me->pos())) {
@@ -676,64 +866,94 @@ bool CWksItemDelegate::helpEventProject(const QPoint& pos, const QPoint& posGlob
         rectAutoSyncDev] = getRectanglesProject(opt, item);
   if (rectVisible.contains(pos)) {
     if (item.isVisible()) {
-      QToolTip::showText(posGlobal, trRichText("Hide project on map."), view, {}, 3000);
+      QToolTip::showText(posGlobal, toRichText(tr("Hide project on map.")), view, {}, 3000);
     } else {
-      QToolTip::showText(posGlobal, trRichText("Show project on map."), view, {}, 3000);
+      QToolTip::showText(posGlobal, toRichText(tr("Show project on map.")), view, {}, 3000);
     }
     return true;
   } else if (rectSave.contains(pos)) {
-    if (item.isChanged() && !item.isAutoSave()) {
-      QToolTip::showText(posGlobal, trRichText("Save project."), view, {}, 3000);
-    } else {
-      if (item.isAutoSave()) {
-        QToolTip::showText(posGlobal, trRichText("Disable auto save."), view, {}, 3000);
-      } else if (item.canSave()) {
-        QToolTip::showText(posGlobal, trRichText("Enable auto save."), view, {}, 3000);
+    if (item.isOnDevice() == false) {
+      if (item.isChanged() && !item.isAutoSave()) {
+        QToolTip::showText(posGlobal, toRichText(tr("Save project.")), view, {}, 3000);
+      } else {
+        if (item.isAutoSave()) {
+          QToolTip::showText(posGlobal, toRichText(tr("Disable auto save.")), view, {}, 3000);
+        } else if (item.canSave()) {
+          QToolTip::showText(posGlobal, toRichText(tr("Enable auto save.")), view, {}, 3000);
+        }
       }
+    } else {
+      QToolTip::showText(posGlobal, toRichText(tr("Copy content of project into a project in the workspace.")), view,
+                         {}, 3000);
     }
     return true;
   } else if (rectAutoSyncDev.contains(pos)) {
     if (item.isAutoSyncToDev()) {
-      QToolTip::showText(posGlobal, trRichText("Disable automatic synchonization with GPS device."), view, {}, 3000);
+      QToolTip::showText(posGlobal, toRichText(tr("Disable automatic synchonization with GPS device.")), view, {},
+                         3000);
     } else {
-      QToolTip::showText(posGlobal, trRichText("Enable automatic synchonization with GPS device."), view, {}, 3000);
+      QToolTip::showText(posGlobal, toRichText(tr("Enable automatic synchonization with GPS device.")), view, {}, 3000);
     }
     return true;
   } else if (rectActiveProject.contains(pos)) {
     if (item.hasUserFocus()) {
       QToolTip::showText(
           posGlobal,
-          trRichText("This is the active project. All new items will be attached to this project automatically."), view,
-          {}, 5000);
+          toRichText(tr("This is the active project. All new items will be attached to this project automatically.")),
+          view, {}, 5000);
     } else {
       QToolTip::showText(
           posGlobal,
-          trRichText("Make this project the active one. All new items will be attached to this project automatically."),
+          toRichText(
+              tr("Make this project the active one. All new items will be attached to this project automatically.")),
           view, {}, 5000);
     }
     return true;
-  } else if (rectName.contains(pos) || rectStatus.contains(pos)) {
+  } else if (rectName.contains(pos)) {
     QToolTip::showText(posGlobal, item.getInfo(IWksItem::eFeatureShowName), view);
     return true;
+  } else if (rectStatus.contains(pos)) {
+    if (itemStatusControl.prj.flags == 0) {
+      QToolTip::showText(
+          posGlobal,
+          toRichText(
+              tr("This is the status line. You can select additional information to be displayed in the workspace "
+                 "setup. See menu->Workspace->Setup Workspace")),
+          view, {}, 5000);
+    } else {
+      QToolTip::showText(posGlobal, item.getInfo(IWksItem::eFeatureShowName), view);
+    }
+    return true;
   }
   return false;
 }
 
 bool CWksItemDelegate::helpEventItem(const QPoint& pos, const QPoint& posGlobal, QAbstractItemView* view,
                                      const QStyleOptionViewItem& opt, const IWksItem& item) {
-  bool ret = false;
   auto [fontName, fontStatus, rectIcon, rectName, rectStatus, rectChanged] = getRectanglesItem(opt, item);
 
   if (rectName.contains(pos)) {
     QToolTip::showText(posGlobal, item.getInfo(IWksItem::eFeatureShowName), view);
-    ret = true;
+    return true;
+  } else if (rectStatus.contains(pos)) {
+    if (itemStatusControl.prj.flags == 0) {
+      QToolTip::showText(
+          posGlobal,
+          toRichText(
+              tr("This is the status line. You can select additional information to be displayed in the workspace "
+                 "setup. See menu->Workspace->Setup Workspace")),
+          view, {}, 5000);
+    } else {
+      QToolTip::showText(posGlobal, item.getInfo(IWksItem::eFeatureShowName), view);
+    }
+    return true;
   } else if (rectChanged.contains(pos)) {
     if (item.isChanged()) {
-      QToolTip::showText(posGlobal, trRichText("Item is changed and needs to be saved."), view, {}, 3000);
-      ret = true;
+      QToolTip::showText(posGlobal, toRichText(tr("Item is changed and needs to be saved.")), view, {}, 3000);
+      return true;
     }
   }
-  return ret;
+  return false;
 }
 
 bool CWksItemDelegate::helpEventGeoSearch(const QPoint& pos, const QPoint& posGlobal, QAbstractItemView* view,
@@ -741,7 +961,7 @@ bool CWksItemDelegate::helpEventGeoSearch(const QPoint& pos, const QPoint& posGl
   auto [fontSearch, fontStatus, rectIcon, rectSetup, rectLineEdit, rectStatus, rectWptIcon, rectVisible] =
       getRectanglesGeoSearch(opt);
   if (rectSetup.contains(pos)) {
-    QToolTip::showText(posGlobal, trRichText("Setup Search"), view, {}, 3000);
+    QToolTip::showText(posGlobal, toRichText(tr("Setup Search")), view, {}, 3000);
     return true;
   }
 
