@@ -81,14 +81,15 @@ void CAppSetupMac::initQMapShack() {
   const QString& style(QLatin1String(styleFile.readAll()));
   app->setStyleSheet(style);
 
-  migrateDirContent(defaultCachePath());
-  migrateDirContent(userDataPath());
-
   // create directories
   IAppSetup::path(defaultCachePath(), 0, true, "CACHE");
-  IAppSetup::path(userDataPath("WaypointIcons"), 0, true, "USER DATA");
+  IAppSetup::path(userDataPath(), 0, true, "USER DATA");
+  IAppSetup::path(userDataPath("WaypointIcons"), 0, true, "ICON");
   IAppSetup::path(logDir(), 0, false, "LOG");
 
+  migrateDirContent(defaultCachePath());
+  migrateDirContent(userDataPath());
+
   // catch signal SIGTERM
   closeOnSIGTERM();
 }
@@ -99,21 +100,18 @@ QString CAppSetupMac::routinoPath(QString xmlFile) {
 }
 
 QString CAppSetupMac::defaultCachePath() {
-  const QString& cachePath = QStandardPaths::standardLocations(QStandardPaths::CacheLocation).at(0);
+  const QString& cachePath = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
   return IAppSetup::path(cachePath, 0, false, 0);
 }
 
 QString CAppSetupMac::userDataPath(QString subdir) {
-  const QString& dataDir = QStandardPaths::standardLocations(QStandardPaths::AppLocalDataLocation).at(0);
+  const QString& dataDir = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
   return IAppSetup::path(dataDir, subdir, false, 0);
 }
 
 QString CAppSetupMac::logDir() {
-  // home location returns / (root) instead of user home...
-  const QString& home = QStandardPaths::standardLocations(QStandardPaths::DesktopLocation).at(0);
-  QDir dir = QDir(home);
-  dir.cdUp();
-  return IAppSetup::path(dir.absolutePath(), relLogDir, false, 0);
+  const QString& home = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+  return IAppSetup::path(home, relLogDir, false, 0);
 }
 
 QDir CAppSetupMac::getApplicationDir(QString subdir) {
